<?php

namespace App\Filament\Admin\Resources\InvoiceReportResource\Pages;

use App\Enums\IconEnum;
use App\Enums\InvoiceStatus;
use App\Filament\Admin\Resources\InvoiceReportResource;
use Filament\Actions;
use Filament\Resources\Pages\ListRecords;

class ListInvoiceReports extends ListRecords
{
    protected static string $resource = InvoiceReportResource::class;

    protected static ?string $title = 'Invoice Reports';

    protected function getHeaderActions(): array
    {
        return [
            Actions\CreateAction::make()
                ->modalWidth('xl')
                ->icon(IconEnum::NEW->value)
                ->mutateFormDataUsing(function ($data) {
                    /* Initialize all payment statues to false,
                       map selected payment types to corresponding status,
                       assign filtered statuses to specific keys */

                    $paymentTypes = array_fill_keys(array_map(fn ($status) => $status->name, InvoiceStatus::cases()), false);

                    if (! empty($data['payment_types'])) {
                        foreach ($data['payment_types'] as $type) {
                            $statusName                = InvoiceStatus::from($type)->name;
                            $paymentTypes[$statusName] = true;
                        }
                    }

                    foreach ($paymentTypes as $status => $value) {
                        $data['with_'.strtolower($status)] = $value;
                    }

                    unset($data['payment_types']);

                    return $data;
                }),
        ];
    }
}
